@@ -1,4 +1,8 @@
 /*
+ * SPDX-License-Identifier: BSD-3-Clause
+ *
+ * https://opensource.org/license/bsd-3-clause
+ *
  * Copyright (C) 2011, 2012, 2013, 2014 Citrix Systems
  *
  * All rights reserved.
@@ -54,25 +58,26 @@ struct http_headers {
 
 static void write_http_echo(ioa_socket_handle s) {
   if (s && !ioa_socket_tobeclosed(s)) {
-    SOCKET_APP_TYPE sat = get_ioa_socket_app_type(s);
+    const SOCKET_APP_TYPE sat = get_ioa_socket_app_type(s);
     if ((sat == HTTP_CLIENT_SOCKET) || (sat == HTTPS_CLIENT_SOCKET)) {
-      ioa_network_buffer_handle nbh_http = ioa_network_buffer_allocate(s->e);
-      size_t len_http = ioa_network_buffer_get_size(nbh_http);
-      uint8_t *data = ioa_network_buffer_data(nbh_http);
-      char data_http[1025];
       char content_http[1025];
-      const char *title = "TURN Server";
+      const char *const title = "TURN Server";
       snprintf(content_http, sizeof(content_http) - 1,
                "<!DOCTYPE html>\r\n<html>\r\n  <head>\r\n    <title>%s</title>\r\n  </head>\r\n  <body>\r\n    "
                "<b>%s</b> <br> <b><i>use https connection for the admin session</i></b>\r\n  </body>\r\n</html>\r\n",
                title, title);
-      snprintf(
-          data_http, sizeof(data_http) - 1,
-          "HTTP/1.0 200 OK\r\nServer: %s\r\nContent-Type: text/html; charset=UTF-8\r\nContent-Length: %d\r\n\r\n%.906s",
-          TURN_SOFTWARE, (int)strlen(content_http), content_http);
-      len_http = strlen(data_http);
-      memcpy(data, data_http, len_http);
-      ioa_network_buffer_set_size(nbh_http, len_http);
+
+      char data_http[1025];
+      snprintf(data_http, sizeof(data_http) - 1,
+               "HTTP/1.0 200 OK\r\nServer: %s\r\nContent-Type: text/html; charset=UTF-8\r\nContent-Length: "
+               "%zu\r\n\r\n%.906s",
+               TURN_SOFTWARE, strlen(content_http), content_http);
+
+      ioa_network_buffer_handle nbh_http = ioa_network_buffer_allocate(s->e);
+      char *data = (char *)ioa_network_buffer_data(nbh_http);
+
+      strcpy(data, data_http);
+      ioa_network_buffer_set_size(nbh_http, strlen(data_http));
       send_data_from_ioa_socket_nbh(s, NULL, nbh_http, TTL_IGNORE, TOS_IGNORE, NULL);
     }
   }
@@ -86,7 +91,7 @@ const char *get_http_date_header(void) {
   static const char *wds[] = {"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"};
   static const char *mons[] = {"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"};
 
-  time_t now = time(NULL);
+  const time_t now = time(NULL);
   struct tm *gmtm = gmtime(&now);
 
   buffer_header[0] = 0;
@@ -115,7 +120,7 @@ static struct headers_list *post_parse(char *data, size_t data_len) {
       memcpy(post_data, data, data_len);
       char *fmarker = NULL;
       char *fsplit = strtok_r(post_data, "&", &fmarker);
-      struct headers_list *list = (struct headers_list *)calloc(sizeof(struct headers_list), 1);
+      struct headers_list *list = (struct headers_list *)calloc(1, sizeof(struct headers_list));
       while (fsplit != NULL) {
         char *vmarker = NULL;
         char *key = strtok_r(fsplit, "=", &vmarker);
@@ -168,7 +173,7 @@ static struct http_request *parse_http_request_1(struct http_request *ret, char
 
         const char *query = evhttp_uri_get_query(uri);
         if (query) {
-          struct evkeyvalq *kv = (struct evkeyvalq *)calloc(sizeof(struct evkeyvalq), 1);
+          struct evkeyvalq *kv = (struct evkeyvalq *)calloc(1, sizeof(struct evkeyvalq));
           if (evhttp_parse_query_str(query, kv) < 0) {
             free(ret);
             ret = NULL;
@@ -177,7 +182,7 @@ static struct http_request *parse_http_request_1(struct http_request *ret, char
               free(kv);
             }
           } else {
-            ret->headers = (struct http_headers *)calloc(sizeof(struct http_headers), 1);
+            ret->headers = (struct http_headers *)calloc(1, sizeof(struct http_headers));
             ret->headers->uri_headers = kv;
           }
         }
@@ -193,7 +198,7 @@ static struct http_request *parse_http_request_1(struct http_request *ret, char
           char *body = strstr(s + 1, "\r\n\r\n");
           if (body && body[0]) {
             if (!ret->headers) {
-              ret->headers = (struct http_headers *)calloc(sizeof(struct http_headers), 1);
+              ret->headers = (struct http_headers *)calloc(1, sizeof(struct http_headers));
             }
             ret->headers->post_headers = post_parse(body, strlen(body));
           }
@@ -213,7 +218,12 @@ struct http_request *parse_http_request(char *request) {
 
   if (request) {
 
-    ret = (struct http_request *)calloc(sizeof(struct http_request), 1);
+    ret = (struct http_request *)calloc(1, sizeof(struct http_request));
+
+    if (ret == NULL) {
+      TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "%s: failure in call to calloc \n", __FUNCTION__);
+      return NULL;
+    }
 
     if (strstr(request, "GET ") == request) {
       ret->rtype = HRT_GET;
@@ -330,7 +340,7 @@ struct str_buffer {
 };
 
 struct str_buffer *str_buffer_new(void) {
-  struct str_buffer *ret = (struct str_buffer *)calloc(sizeof(struct str_buffer), 1);
+  struct str_buffer *ret = (struct str_buffer *)calloc(1, sizeof(struct str_buffer));
   if (!ret) {
     return NULL;
   }
@@ -346,7 +356,7 @@ struct str_buffer *str_buffer_new(void) {
 
 void str_buffer_append(struct str_buffer *sb, const char *str) {
   if (sb && str && str[0]) {
-    size_t len = strlen(str);
+    const size_t len = strlen(str);
     while (sb->sz + len + 1 > sb->capacity) {
       sb->capacity += len + 1024;
       sb->buffer = (char *)realloc(sb->buffer, sb->capacity);
