@@ -1,3 +1,37 @@
+/*
+ * SPDX-License-Identifier: BSD-3-Clause
+ *
+ * https://opensource.org/license/bsd-3-clause
+ *
+ * Copyright (C) 2020 Miquel Ortega
+ *
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. Neither the name of the project nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE PROJECT AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE PROJECT OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
 #include "prom_server.h"
 #include "mainrelay.h"
 #include "ns_turn_utils.h"
@@ -9,6 +43,9 @@
 
 #if !defined(TURN_NO_PROMETHEUS)
 
+prom_counter_t *packet_processed;
+prom_counter_t *packet_dropped;
+
 prom_counter_t *stun_binding_request;
 prom_counter_t *stun_binding_response;
 prom_counter_t *stun_binding_error;
@@ -52,10 +89,15 @@ MHD_RESULT promhttp_handler(void *cls, struct MHD_Connection *connection, const
   if (strcmp(method, "GET") != 0) {
     status = MHD_HTTP_METHOD_NOT_ALLOWED;
     body = "method not allowed";
-  } else if (strcmp(url, "/metrics") == 0) {
+  } else if (strcmp(url, turn_params.prometheus_path) == 0) {
     body = prom_collector_registry_bridge(PROM_COLLECTOR_REGISTRY_DEFAULT);
     mode = MHD_RESPMEM_MUST_FREE;
     status = MHD_HTTP_OK;
+  } else if (strcmp(url, "/") == 0) {
+    // Return 200 OK for root path as a health check
+    body = "ok";
+    mode = MHD_RESPMEM_PERSISTENT;
+    status = MHD_HTTP_OK;
   }
 
   struct MHD_Response *response = MHD_create_response_from_buffer(strlen(body), body, mode);
@@ -65,6 +107,7 @@ MHD_RESULT promhttp_handler(void *cls, struct MHD_Connection *connection, const
     }
     ret = MHD_NO;
   } else {
+    MHD_add_response_header(response, "Content-Type", "text/plain");
     ret = MHD_queue_response(connection, status, response);
     MHD_destroy_response(response);
   }
@@ -72,7 +115,7 @@ MHD_RESULT promhttp_handler(void *cls, struct MHD_Connection *connection, const
 }
 
 void start_prometheus_server(void) {
-  if (turn_params.prometheus == 0) {
+  if (!turn_params.prometheus) {
     TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "prometheus collector disabled, not started\n");
     return;
   }
@@ -138,6 +181,11 @@ void start_prometheus_server(void) {
   const char *typeLabel[] = {"type"};
   turn_total_allocations = prom_collector_registry_must_register_metric(
       prom_gauge_new("turn_total_allocations", "Represents current allocations number", 1, typeLabel));
+  // Packet counters
+  packet_processed = prom_collector_registry_must_register_metric(
+      prom_counter_new("turn_packet_processed", "Incoming packet processed", 0, NULL));
+  packet_dropped = prom_collector_registry_must_register_metric(
+      prom_counter_new("turn_packet_dropped", "Incoming packet dropped", 0, NULL));
 
   // some flags appeared first in microhttpd v0.9.53
   unsigned int flags = 0;
@@ -194,13 +242,11 @@ void start_prometheus_server(void) {
   }
 
   TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "prometheus collector started successfully\n");
-
-  return;
 }
 
 void prom_set_finished_traffic(const char *realm, const char *user, unsigned long rsvp, unsigned long rsvb,
                                unsigned long sentp, unsigned long sentb, bool peer) {
-  if (turn_params.prometheus == 1) {
+  if (turn_params.prometheus) {
 
     const char *label[] = {realm, NULL};
     if (turn_params.prometheus_username_labels) {
@@ -232,33 +278,45 @@ void prom_set_finished_traffic(const char *realm, const char *user, unsigned lon
 }
 
 void prom_inc_allocation(SOCKET_TYPE type) {
-  if (turn_params.prometheus == 1) {
+  if (turn_params.prometheus) {
     const char *label[] = {socket_type_name(type)};
     prom_gauge_inc(turn_total_allocations, label);
   }
 }
 
 void prom_dec_allocation(SOCKET_TYPE type) {
-  if (turn_params.prometheus == 1) {
+  if (turn_params.prometheus) {
     const char *label[] = {socket_type_name(type)};
     prom_gauge_dec(turn_total_allocations, label);
   }
 }
 
-void prom_inc_stun_binding_request(void) {
+void prom_inc_packet_processed(int count) {
   if (turn_params.prometheus == 1) {
+    prom_counter_add(packet_processed, count, NULL);
+  }
+}
+
+void prom_inc_packet_dropped(int count) {
+  if (turn_params.prometheus == 1) {
+    prom_counter_add(packet_dropped, count, NULL);
+  }
+}
+
+void prom_inc_stun_binding_request(void) {
+  if (turn_params.prometheus) {
     prom_counter_add(stun_binding_request, 1, NULL);
   }
 }
 
 void prom_inc_stun_binding_response(void) {
-  if (turn_params.prometheus == 1) {
+  if (turn_params.prometheus) {
     prom_counter_add(stun_binding_response, 1, NULL);
   }
 }
 
 void prom_inc_stun_binding_error(void) {
-  if (turn_params.prometheus == 1) {
+  if (turn_params.prometheus) {
     prom_counter_add(stun_binding_error, 1, NULL);
   }
 }
@@ -301,4 +359,8 @@ void prom_inc_allocation(SOCKET_TYPE type) { UNUSED_ARG(type); }
 
 void prom_dec_allocation(SOCKET_TYPE type) { UNUSED_ARG(type); }
 
+void prom_inc_packet_processed(int count) { UNUSED_ARG(count); }
+
+void prom_inc_packet_dropped(int count) { UNUSED_ARG(count); }
+
 #endif /* TURN_NO_PROMETHEUS */
