@@ -1,4 +1,8 @@
 /*
+ * SPDX-License-Identifier: BSD-3-Clause
+ *
+ * https://opensource.org/license/bsd-3-clause
+ *
  * Copyright (C) 2011, 2012, 2013 Citrix Systems
  *
  * All rights reserved.
@@ -55,23 +59,21 @@ static uint64_t current_reservation_token = 0;
 static int allocate_rtcp = 0;
 static const int never_allocate_rtcp = 0;
 
-#if ALPN_SUPPORTED
 static const unsigned char kALPNProtos[] = "\x08http/1.1\x09stun.turn\x12stun.nat-discovery";
 static const size_t kALPNProtosLen = sizeof(kALPNProtos) - 1;
-#endif
 
 /////////////////////////////////////////
 
 int rare_event(void) {
   if (dos) {
-    return (((unsigned long)turn_random()) % 1000 == 777);
+    return (((unsigned long)turn_random_number()) % 1000 == 777);
   }
   return 0;
 }
 
 int not_rare_event(void) {
   if (dos) {
-    return ((((unsigned long)turn_random()) % 1000) < 200);
+    return ((((unsigned long)turn_random_number()) % 1000) < 200);
   }
   return 0;
 }
@@ -90,15 +92,11 @@ static int get_allocate_address_family(ioa_addr *relay_addr) {
 
 static SSL *tls_connect(ioa_socket_raw fd, ioa_addr *remote_addr, bool *try_again, int connect_cycle) {
 
-  int ctxtype = (int)(((unsigned long)turn_random()) % root_tls_ctx_num);
+  const int ctxtype = (int)(((unsigned long)turn_random_number()) % root_tls_ctx_num);
 
-  SSL *ssl;
+  SSL *const ssl = SSL_new(root_tls_ctx[ctxtype]);
 
-  ssl = SSL_new(root_tls_ctx[ctxtype]);
-
-#if ALPN_SUPPORTED
   SSL_set_alpn_protos(ssl, kALPNProtos, kALPNProtosLen);
-#endif
 
   if (use_tcp) {
     SSL_set_fd(ssl, fd);
@@ -140,7 +138,7 @@ static SSL *tls_connect(ioa_socket_raw fd, ioa_addr *remote_addr, bool *try_agai
     do {
       rc = SSL_connect(ssl);
     } while (rc < 0 && socket_eintr());
-    int orig_errno = socket_errno();
+    const int orig_errno = socket_errno();
     if (rc > 0) {
       TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "%s: client session connected with cipher %s, method=%s\n", __FUNCTION__,
                     SSL_get_cipher(ssl), turn_get_ssl_method(ssl, NULL));
@@ -216,17 +214,12 @@ static int clnet_connect(uint16_t clnet_remote_port, const char *remote_address,
                          const char *local_address, bool verbose, app_ur_conn_info *clnet_info) {
 
   ioa_addr local_addr;
-  evutil_socket_t clnet_fd;
-  int connect_err;
   int connect_cycle = 0;
 
   ioa_addr remote_addr;
 
 start_socket:
 
-  clnet_fd = -1;
-  connect_err = 0;
-
   memset(&remote_addr, 0, sizeof(ioa_addr));
   if (make_ioa_addr((const uint8_t *)remote_address, clnet_remote_port, &remote_addr) < 0) {
     return -1;
@@ -234,11 +227,11 @@ start_socket:
 
   memset(&local_addr, 0, sizeof(ioa_addr));
 
-  clnet_fd = socket(remote_addr.ss.sa_family,
-                    use_sctp ? SCTP_CLIENT_STREAM_SOCKET_TYPE
-                             : (use_tcp ? CLIENT_STREAM_SOCKET_TYPE : CLIENT_DGRAM_SOCKET_TYPE),
-                    use_sctp ? SCTP_CLIENT_STREAM_SOCKET_PROTOCOL
-                             : (use_tcp ? CLIENT_STREAM_SOCKET_PROTOCOL : CLIENT_DGRAM_SOCKET_PROTOCOL));
+  evutil_socket_t clnet_fd = socket(
+      remote_addr.ss.sa_family,
+      use_sctp ? SCTP_CLIENT_STREAM_SOCKET_TYPE : (use_tcp ? CLIENT_STREAM_SOCKET_TYPE : CLIENT_DGRAM_SOCKET_TYPE),
+      use_sctp ? SCTP_CLIENT_STREAM_SOCKET_PROTOCOL
+               : (use_tcp ? CLIENT_STREAM_SOCKET_PROTOCOL : CLIENT_DGRAM_SOCKET_PROTOCOL));
   if (clnet_fd < 0) {
     perror("socket");
     exit(-1);
@@ -279,6 +272,7 @@ start_socket:
     addr_bind(clnet_fd, &local_addr, 0, 1, get_socket_type());
   }
 
+  int connect_err = 0;
   if (clnet_info->is_peer) {
     ;
   } else if (socket_connect(clnet_fd, &remote_addr, &connect_err) > 0) {
@@ -295,7 +289,7 @@ start_socket:
     STRCPY(clnet_info->ifname, (const char *)ifname);
   }
 
-  if (use_secure) {
+  if (use_secure && clnet_info) {
     bool try_again = false;
     clnet_info->ssl = tls_connect(clnet_info->fd, &remote_addr, &try_again, connect_cycle++);
     if (!clnet_info->ssl) {
@@ -322,9 +316,9 @@ start_socket:
 int read_mobility_ticket(app_ur_conn_info *clnet_info, stun_buffer *message) {
   int ret = 0;
   if (clnet_info && message) {
-    stun_attr_ref s_mobile_id_sar = stun_attr_get_first_by_type(message, STUN_ATTRIBUTE_MOBILITY_TICKET);
+    const stun_attr_ref s_mobile_id_sar = stun_attr_get_first_by_type(message, STUN_ATTRIBUTE_MOBILITY_TICKET);
     if (s_mobile_id_sar) {
-      int smid_len = stun_attr_get_len(s_mobile_id_sar);
+      const int smid_len = stun_attr_get_len(s_mobile_id_sar);
       if (smid_len > 0 && (((size_t)smid_len) < sizeof(clnet_info->s_mobile_id))) {
         const uint8_t *smid_val = stun_attr_get_value(s_mobile_id_sar);
         if (smid_val) {
@@ -345,11 +339,15 @@ int read_mobility_ticket(app_ur_conn_info *clnet_info, stun_buffer *message) {
 
 void add_origin(stun_buffer *message) {
   if (message && origin[0]) {
-    const char *some_origin = "https://carleon.gov:443";
-    stun_attr_add(message, STUN_ATTRIBUTE_ORIGIN, some_origin, strlen(some_origin));
+    {
+      const char *const some_origin = "https://carleon.gov:443";
+      stun_attr_add(message, STUN_ATTRIBUTE_ORIGIN, some_origin, strlen(some_origin));
+    }
     stun_attr_add(message, STUN_ATTRIBUTE_ORIGIN, origin, strlen(origin));
-    some_origin = "ftp://uffrith.net";
-    stun_attr_add(message, STUN_ATTRIBUTE_ORIGIN, some_origin, strlen(some_origin));
+    {
+      const char *const some_origin = "ftp://uffrith.net";
+      stun_attr_add(message, STUN_ATTRIBUTE_ORIGIN, some_origin, strlen(some_origin));
+    }
   }
 }
 
@@ -381,8 +379,8 @@ beg_allocate:
       reopen_socket = false;
     }
 
-    int af4 = dual_allocation || (af == STUN_ATTRIBUTE_REQUESTED_ADDRESS_FAMILY_VALUE_IPV4);
-    int af6 = dual_allocation || (af == STUN_ATTRIBUTE_REQUESTED_ADDRESS_FAMILY_VALUE_IPV6);
+    const int af4 = dual_allocation || (af == STUN_ATTRIBUTE_REQUESTED_ADDRESS_FAMILY_VALUE_IPV4);
+    const int af6 = dual_allocation || (af == STUN_ATTRIBUTE_REQUESTED_ADDRESS_FAMILY_VALUE_IPV6);
 
     uint64_t reservation_token = 0;
     char *rt = NULL;
@@ -402,7 +400,7 @@ beg_allocate:
     } else if (rt) {
       ep = -1;
     } else if (!ep) {
-      ep = (((uint8_t)turn_random()) % 2);
+      ep = (((uint8_t)turn_random_number()) % 2);
       ep = ep - 1;
     }
 
@@ -432,7 +430,7 @@ beg_allocate:
 
     while (!allocate_sent) {
 
-      int len = send_buffer(clnet_info, &request_message, 0, 0);
+      const int len = send_buffer(clnet_info, &request_message, 0, 0);
 
       if (len > 0) {
         if (verbose) {
@@ -456,7 +454,7 @@ beg_allocate:
       bool allocate_received = false;
       while (!allocate_received) {
 
-        int len = recv_buffer(clnet_info, &response_message, 1, 0, NULL, &request_message);
+        const int len = recv_buffer(clnet_info, &response_message, 1, 0, NULL, &request_message);
 
         if (len > 0) {
           if (verbose) {
@@ -484,7 +482,7 @@ beg_allocate:
               stun_attr_ref sar = stun_attr_get_first(&response_message);
               while (sar) {
 
-                int attr_type = stun_attr_get_type(sar);
+                const int attr_type = stun_attr_get_type(sar);
                 if (attr_type == STUN_ATTRIBUTE_XOR_RELAYED_ADDRESS) {
 
                   if (!stun_attr_get_addr(&response_message, sar, relay_addr, NULL)) {
@@ -525,8 +523,9 @@ beg_allocate:
               }
             }
 
-            stun_attr_ref rt_sar = stun_attr_get_first_by_type(&response_message, STUN_ATTRIBUTE_RESERVATION_TOKEN);
-            uint64_t rtv = stun_attr_get_reservation_token_value(rt_sar);
+            const stun_attr_ref rt_sar =
+                stun_attr_get_first_by_type(&response_message, STUN_ATTRIBUTE_RESERVATION_TOKEN);
+            const uint64_t rtv = stun_attr_get_reservation_token_value(rt_sar);
             current_reservation_token = rtv;
             if (verbose) {
               TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "%s: rtv=%llu\n", __FUNCTION__, (long long unsigned int)rtv);
@@ -562,7 +561,6 @@ beg_allocate:
 
             TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "error %d (%s)\n", err_code, (char *)err_msg);
             if (err_code != 437) {
-              allocate_finished = true;
               current_reservation_token = 0;
               return -1;
             } else {
@@ -604,10 +602,10 @@ beg_allocate:
       int fd = clnet_info->fd;
       SSL *ssl = clnet_info->ssl;
 
-      bool close_now = turn_random() % 2;
+      const bool close_now = turn_random_number() % 2;
 
       if (close_now) {
-        bool close_socket = (int)(turn_random() % 2);
+        const bool close_socket = (int)(turn_random_number() % 2);
         if (ssl && !close_socket) {
           SSL_shutdown(ssl);
           SSL_free(ssl);
@@ -660,14 +658,14 @@ beg_allocate:
       }
 
       if (dual_allocation && !mobility) {
-        // TODO: This could be reworked
-        // it's using t as a tri-state to determine whether to add the requested address family field
-        // it should be two seperate bools for readability purposes though.
-        uint8_t t = ((uint8_t)turn_random()) % 3;
-        if (t) {
+        const uint8_t rand = (uint8_t)turn_random_number();
+        bool add_requested_family = rand & 0x01;
+        bool use_ipv4 = rand & 0x02;
+
+        if (add_requested_family) {
           uint8_t field[4];
-          field[0] = (t == 1) ? (uint8_t)STUN_ATTRIBUTE_REQUESTED_ADDRESS_FAMILY_VALUE_IPV4
-                              : (uint8_t)STUN_ATTRIBUTE_REQUESTED_ADDRESS_FAMILY_VALUE_IPV6;
+          field[0] = (use_ipv4) ? (uint8_t)STUN_ATTRIBUTE_REQUESTED_ADDRESS_FAMILY_VALUE_IPV4
+                                : (uint8_t)STUN_ATTRIBUTE_REQUESTED_ADDRESS_FAMILY_VALUE_IPV6;
           field[1] = 0;
           field[2] = 0;
           field[3] = 0;
@@ -685,7 +683,7 @@ beg_allocate:
 
       while (!refresh_sent) {
 
-        int len = send_buffer(clnet_info, &request_message, 0, 0);
+        const int len = send_buffer(clnet_info, &request_message, 0, 0);
 
         if (len > 0) {
           if (verbose) {
@@ -763,7 +761,7 @@ static int turn_channel_bind(bool verbose, uint16_t *chn, app_ur_conn_info *clne
 beg_bind:
 
   if (negative_test) {
-    *chn = stun_set_channel_bind_request(&request_message, peer_addr, (uint16_t)turn_random());
+    *chn = stun_set_channel_bind_request(&request_message, peer_addr, (uint16_t)turn_random_number());
   } else {
     *chn = stun_set_channel_bind_request(&request_message, peer_addr, *chn);
   }
@@ -780,7 +778,7 @@ beg_bind:
 
   while (!cb_sent) {
 
-    int len = send_buffer(clnet_info, &request_message, 0, 0);
+    const int len = send_buffer(clnet_info, &request_message, 0, 0);
     if (len > 0) {
       if (verbose) {
         TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "channel bind sent\n");
@@ -804,7 +802,7 @@ beg_bind:
     bool cb_received = false;
     while (!cb_received) {
 
-      int len = recv_buffer(clnet_info, &response_message, 1, 0, NULL, &request_message);
+      const int len = recv_buffer(clnet_info, &response_message, 1, 0, NULL, &request_message);
       if (len > 0) {
         if (verbose) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "cb response received: \n");
@@ -829,7 +827,6 @@ beg_bind:
                                                   clnet_info->server_name, &(clnet_info->oauth))) {
           goto beg_bind;
         } else if (stun_is_error_response(&response_message, &err_code, err_msg, sizeof(err_msg))) {
-          cb_received = true;
           TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "channel bind: error %d (%s)\n", err_code, (char *)err_msg);
           return -1;
         } else {
@@ -879,7 +876,7 @@ beg_cp:
 
   while (!cp_sent) {
 
-    int len = send_buffer(clnet_info, &request_message, 0, 0);
+    const int len = send_buffer(clnet_info, &request_message, 0, 0);
 
     if (len > 0) {
       if (verbose) {
@@ -904,7 +901,7 @@ beg_cp:
     bool cp_received = false;
     while (!cp_received) {
 
-      int len = recv_buffer(clnet_info, &response_message, 1, 0, NULL, &request_message);
+      const int len = recv_buffer(clnet_info, &response_message, 1, 0, NULL, &request_message);
       if (len > 0) {
         if (verbose) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "cp response received: \n");
@@ -929,7 +926,6 @@ beg_cp:
                                                   clnet_info->server_name, &(clnet_info->oauth))) {
           goto beg_cp;
         } else if (stun_is_error_response(&response_message, &err_code, err_msg, sizeof(err_msg))) {
-          cp_received = true;
           TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "create permission error %d (%s)\n", err_code, (char *)err_msg);
           return -1;
         } else {
@@ -1040,21 +1036,21 @@ int start_connection(uint16_t clnet_remote_port0, const char *remote_address0, c
 
       if (extra_requests) {
         const char *sarbaddr = "164.156.178.190";
-        if (turn_random() % 2 == 0) {
+        if (turn_random_number() % 2 == 0) {
           sarbaddr = "2001::172";
         }
         ioa_addr arbaddr;
         make_ioa_addr((const uint8_t *)sarbaddr, 333, &arbaddr);
-        int maxi = (unsigned short)turn_random() % EXTRA_CREATE_PERMS;
+        const int maxi = (unsigned short)turn_random_number() % EXTRA_CREATE_PERMS;
         for (int i = 0; i < maxi; i++) {
           uint16_t chni = 0;
-          int port = (unsigned short)turn_random();
+          int port = (unsigned short)turn_random_number();
           if (port < 1024) {
             port += 1024;
           }
           addr_set_port(&arbaddr, port);
-          uint8_t *u = (uint8_t *)&(arbaddr.s4.sin_addr);
-          u[(unsigned short)turn_random() % 4] = u[(unsigned short)turn_random() % 4] + 1;
+          uint8_t *const u = (uint8_t *)&(arbaddr.s4.sin_addr);
+          u[(unsigned short)turn_random_number() % 4] = u[(unsigned short)turn_random_number() % 4] + 1;
           // char sss[128];
           // addr_to_string(&arbaddr,(uint8_t*)sss);
           // printf("%s: 111.111: %s\n",__FUNCTION__,sss);
@@ -1073,19 +1069,19 @@ int start_connection(uint16_t clnet_remote_port0, const char *remote_address0, c
 
       if (extra_requests) {
         const char *sarbaddr = "64.56.78.90";
-        if (turn_random() % 2 == 0) {
+        if (turn_random_number() % 2 == 0) {
           sarbaddr = "2001::172";
         }
         ioa_addr arbaddr[EXTRA_CREATE_PERMS];
         make_ioa_addr((const uint8_t *)sarbaddr, 333, &arbaddr[0]);
-        int maxi = (unsigned short)turn_random() % EXTRA_CREATE_PERMS;
+        const int maxi = (unsigned short)turn_random_number() % EXTRA_CREATE_PERMS;
         for (int i = 0; i < maxi; i++) {
           if (i > 0) {
             addr_cpy(&arbaddr[i], &arbaddr[0]);
           }
-          addr_set_port(&arbaddr[i], (unsigned short)turn_random());
-          uint8_t *u = (uint8_t *)&(arbaddr[i].s4.sin_addr);
-          u[(unsigned short)turn_random() % 4] = u[(unsigned short)turn_random() % 4] + 1;
+          addr_set_port(&arbaddr[i], (unsigned short)turn_random_number());
+          uint8_t *const u = (uint8_t *)&(arbaddr[i].s4.sin_addr);
+          u[(unsigned short)turn_random_number() % 4] = u[(unsigned short)turn_random_number() % 4] + 1;
           // char sss[128];
           // addr_to_string(&arbaddr[i],(uint8_t*)sss);
           // printf("%s: 111.111: %s\n",__FUNCTION__,sss);
@@ -1094,7 +1090,7 @@ int start_connection(uint16_t clnet_remote_port0, const char *remote_address0, c
       }
     } else {
 
-      bool const before = turn_random() % 2;
+      const bool before = turn_random_number() % 2;
 
       if (before) {
         if (turn_create_permission(verbose, clnet_info, &peer_addr, 1) < 0) {
@@ -1113,19 +1109,19 @@ int start_connection(uint16_t clnet_remote_port0, const char *remote_address0, c
 
       if (extra_requests) {
         const char *sarbaddr = "64.56.78.90";
-        if (turn_random() % 2) {
+        if (turn_random_number() % 2) {
           sarbaddr = "2001::172";
         }
         ioa_addr arbaddr[EXTRA_CREATE_PERMS];
         make_ioa_addr((const uint8_t *)sarbaddr, 333, &arbaddr[0]);
-        int maxi = (unsigned short)turn_random() % EXTRA_CREATE_PERMS;
+        const int maxi = (unsigned short)turn_random_number() % EXTRA_CREATE_PERMS;
         for (int i = 0; i < maxi; i++) {
           if (i > 0) {
             addr_cpy(&arbaddr[i], &arbaddr[0]);
           }
-          addr_set_port(&arbaddr[i], (unsigned short)turn_random());
-          uint8_t *u = (uint8_t *)&(arbaddr[i].s4.sin_addr);
-          u[(unsigned short)turn_random() % 4] = u[(unsigned short)turn_random() % 4] + 1;
+          addr_set_port(&arbaddr[i], (unsigned short)turn_random_number());
+          uint8_t *const u = (uint8_t *)&(arbaddr[i].s4.sin_addr);
+          u[(unsigned short)turn_random_number() % 4] = u[(unsigned short)turn_random_number() % 4] + 1;
           // char sss[128];
           // addr_to_string(&arbaddr,(uint8_t*)sss);
           // printf("%s: 111.111: %s\n",__FUNCTION__,sss);
@@ -1297,21 +1293,21 @@ int start_c2c_connection(uint16_t clnet_remote_port0, const char *remote_address
 
     if (extra_requests) {
       const char *sarbaddr = "164.156.178.190";
-      if (turn_random() % 2 == 0) {
+      if (turn_random_number() % 2 == 0) {
         sarbaddr = "2001::172";
       }
       ioa_addr arbaddr;
       make_ioa_addr((const uint8_t *)sarbaddr, 333, &arbaddr);
-      int maxi = (unsigned short)turn_random() % EXTRA_CREATE_PERMS;
+      const int maxi = (unsigned short)turn_random_number() % EXTRA_CREATE_PERMS;
       for (int i = 0; i < maxi; i++) {
         uint16_t chni = 0;
-        int port = (unsigned short)turn_random();
+        int port = (unsigned short)turn_random_number();
         if (port < 1024) {
           port += 1024;
         }
         addr_set_port(&arbaddr, port);
-        uint8_t *u = (uint8_t *)&(arbaddr.s4.sin_addr);
-        u[(unsigned short)turn_random() % 4] = u[(unsigned short)turn_random() % 4] + 1;
+        uint8_t *const u = (uint8_t *)&(arbaddr.s4.sin_addr);
+        u[(unsigned short)turn_random_number() % 4] = u[(unsigned short)turn_random_number() % 4] + 1;
         // char sss[128];
         // addr_to_string(&arbaddr,(uint8_t*)sss);
         // printf("%s: 111.111: %s\n",__FUNCTION__,sss);
@@ -1325,19 +1321,19 @@ int start_c2c_connection(uint16_t clnet_remote_port0, const char *remote_address
 
     if (extra_requests) {
       const char *sarbaddr = "64.56.78.90";
-      if (turn_random() % 2 == 0) {
+      if (turn_random_number() % 2 == 0) {
         sarbaddr = "2001::172";
       }
       ioa_addr arbaddr[EXTRA_CREATE_PERMS];
       make_ioa_addr((const uint8_t *)sarbaddr, 333, &arbaddr[0]);
-      int maxi = (unsigned short)turn_random() % EXTRA_CREATE_PERMS;
+      const int maxi = (unsigned short)turn_random_number() % EXTRA_CREATE_PERMS;
       for (int i = 0; i < maxi; i++) {
         if (i > 0) {
           addr_cpy(&arbaddr[i], &arbaddr[0]);
         }
-        addr_set_port(&arbaddr[i], (unsigned short)turn_random());
-        uint8_t *u = (uint8_t *)&(arbaddr[i].s4.sin_addr);
-        u[(unsigned short)turn_random() % 4] = u[(unsigned short)turn_random() % 4] + 1;
+        addr_set_port(&arbaddr[i], (unsigned short)turn_random_number());
+        uint8_t *const u = (uint8_t *)&(arbaddr[i].s4.sin_addr);
+        u[(unsigned short)turn_random_number() % 4] = u[(unsigned short)turn_random_number() % 4] + 1;
         // char sss[128];
         // addr_to_string(&arbaddr[i],(uint8_t*)sss);
         // printf("%s: 111.111: %s\n",__FUNCTION__,sss);
@@ -1375,16 +1371,16 @@ int start_c2c_connection(uint16_t clnet_remote_port0, const char *remote_address
 
     if (extra_requests) {
       const char *sarbaddr = "64.56.78.90";
-      if (turn_random() % 2 == 0) {
+      if (turn_random_number() % 2 == 0) {
         sarbaddr = "2001::172";
       }
       ioa_addr arbaddr;
       make_ioa_addr((const uint8_t *)sarbaddr, 333, &arbaddr);
-      int maxi = (unsigned short)turn_random() % EXTRA_CREATE_PERMS;
+      const int maxi = (unsigned short)turn_random_number() % EXTRA_CREATE_PERMS;
       for (int i = 0; i < maxi; i++) {
-        addr_set_port(&arbaddr, (unsigned short)turn_random());
-        uint8_t *u = (uint8_t *)&(arbaddr.s4.sin_addr);
-        u[(unsigned short)turn_random() % 4] = u[(unsigned short)turn_random() % 4] + 1;
+        addr_set_port(&arbaddr, (unsigned short)turn_random_number());
+        uint8_t *const u = (uint8_t *)&(arbaddr.s4.sin_addr);
+        u[(unsigned short)turn_random_number() % 4] = u[(unsigned short)turn_random_number() % 4] + 1;
         // char sss[128];
         // addr_to_string(&arbaddr,(uint8_t*)sss);
         // printf("%s: 111.111: %s\n",__FUNCTION__,sss);
@@ -1498,7 +1494,7 @@ beg_cb:
 
   while (!cb_sent) {
 
-    int len = send_buffer(clnet_info, &request_message, 1, atc);
+    const int len = send_buffer(clnet_info, &request_message, 1, atc);
 
     if (len > 0) {
       if (verbose) {
@@ -1526,7 +1522,7 @@ beg_cb:
     bool cb_received = false;
     while (!cb_received) {
 
-      int len = recv_buffer(clnet_info, &response_message, 1, 1, atc, &request_message);
+      const int len = recv_buffer(clnet_info, &response_message, 1, 1, atc, &request_message);
       if (len > 0) {
         if (verbose) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "connect bind response received: \n");
@@ -1592,10 +1588,15 @@ again:
   set_sock_buf_size(clnet_fd, (UR_CLIENT_SOCK_BUF_SIZE << 2));
 
   ++elem->pinfo.tcp_conn_number;
-  int i = (int)(elem->pinfo.tcp_conn_number - 1);
+  const int i = (int)(elem->pinfo.tcp_conn_number - 1);
   elem->pinfo.tcp_conn =
       (app_tcp_conn_info **)realloc(elem->pinfo.tcp_conn, elem->pinfo.tcp_conn_number * sizeof(app_tcp_conn_info *));
-  elem->pinfo.tcp_conn[i] = (app_tcp_conn_info *)calloc(sizeof(app_tcp_conn_info), 1);
+  elem->pinfo.tcp_conn[i] = (app_tcp_conn_info *)calloc(1, sizeof(app_tcp_conn_info));
+
+  if (elem->pinfo.tcp_conn[i] == NULL) {
+    TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "%s: failure in call to calloc \n", __FUNCTION__);
+    return;
+  }
 
   elem->pinfo.tcp_conn[i]->tcp_data_fd = clnet_fd;
   elem->pinfo.tcp_conn[i]->cid = cid;
@@ -1608,44 +1609,41 @@ again:
 
   addr_get_from_sock(clnet_fd, &(elem->pinfo.tcp_conn[i]->tcp_data_local_addr));
 
-  {
-    int cycle = 0;
-    while (cycle++ < 1024) {
-      int err = 0;
-      if (addr_connect(clnet_fd, &(elem->pinfo.remote_addr), &err) < 0) {
-        if (err == EADDRINUSE) {
-          socket_closesocket(clnet_fd);
-          clnet_fd =
-              socket(elem->pinfo.remote_addr.ss.sa_family, CLIENT_STREAM_SOCKET_TYPE, CLIENT_STREAM_SOCKET_PROTOCOL);
-          if (clnet_fd < 0) {
-            perror("socket");
-            exit(-1);
-          }
-          if (sock_bind_to_device(clnet_fd, client_ifname) < 0) {
-            TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "Cannot bind client socket to device %s\n", client_ifname);
-          }
-          set_sock_buf_size(clnet_fd, UR_CLIENT_SOCK_BUF_SIZE << 2);
-
-          elem->pinfo.tcp_conn[i]->tcp_data_fd = clnet_fd;
-
-          addr_cpy(&(elem->pinfo.tcp_conn[i]->tcp_data_local_addr), &(elem->pinfo.local_addr));
-
-          addr_set_port(&(elem->pinfo.tcp_conn[i]->tcp_data_local_addr), 0);
-
-          addr_bind(clnet_fd, &(elem->pinfo.tcp_conn[i]->tcp_data_local_addr), 1, 1, TCP_SOCKET);
-
-          addr_get_from_sock(clnet_fd, &(elem->pinfo.tcp_conn[i]->tcp_data_local_addr));
-
-          continue;
-
-        } else {
-          perror("connect");
-          TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "%s: cannot connect to remote addr\n", __FUNCTION__);
+  for (int cycle = 0; cycle < 1024; ++cycle) {
+    int err = 0;
+    if (addr_connect(clnet_fd, &(elem->pinfo.remote_addr), &err) < 0) {
+      if (err == EADDRINUSE) {
+        socket_closesocket(clnet_fd);
+        clnet_fd =
+            socket(elem->pinfo.remote_addr.ss.sa_family, CLIENT_STREAM_SOCKET_TYPE, CLIENT_STREAM_SOCKET_PROTOCOL);
+        if (clnet_fd < 0) {
+          perror("socket");
           exit(-1);
         }
+        if (sock_bind_to_device(clnet_fd, client_ifname) < 0) {
+          TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "Cannot bind client socket to device %s\n", client_ifname);
+        }
+        set_sock_buf_size(clnet_fd, UR_CLIENT_SOCK_BUF_SIZE << 2);
+
+        elem->pinfo.tcp_conn[i]->tcp_data_fd = clnet_fd;
+
+        addr_cpy(&(elem->pinfo.tcp_conn[i]->tcp_data_local_addr), &(elem->pinfo.local_addr));
+
+        addr_set_port(&(elem->pinfo.tcp_conn[i]->tcp_data_local_addr), 0);
+
+        addr_bind(clnet_fd, &(elem->pinfo.tcp_conn[i]->tcp_data_local_addr), 1, 1, TCP_SOCKET);
+
+        addr_get_from_sock(clnet_fd, &(elem->pinfo.tcp_conn[i]->tcp_data_local_addr));
+
+        continue;
+
       } else {
-        break;
+        perror("connect");
+        TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "%s: cannot connect to remote addr\n", __FUNCTION__);
+        exit(-1);
       }
+    } else {
+      break;
     }
   }
 
@@ -1669,7 +1667,7 @@ again:
 
     socket_set_nonblocking(clnet_fd);
 
-    struct event *ev = event_new(client_event_base, clnet_fd, EV_READ | EV_PERSIST, client_input_handler, elem);
+    struct event *const ev = event_new(client_event_base, clnet_fd, EV_READ | EV_PERSIST, client_input_handler, elem);
 
     event_add(ev, NULL);
 
