@@ -1,4 +1,8 @@
 /*
+ * SPDX-License-Identifier: BSD-3-Clause
+ *
+ * https://opensource.org/license/bsd-3-clause
+ *
  * Copyright (C) 2011, 2012, 2013 Citrix Systems
  *
  * All rights reserved.
@@ -192,17 +196,16 @@ static int remove_all_from_ss(app_ur_session *ss) {
 
 int send_buffer(app_ur_conn_info *clnet_info, stun_buffer *message, bool data_connection, app_tcp_conn_info *atc) {
 
-  int rc = 0;
   int ret = -1;
 
   char *buffer = (char *)(message->buf);
 
   if (negative_protocol_test && (message->len > 0)) {
-    if (turn_random() % 10 == 0) {
-      int np = (int)((unsigned long)turn_random() % 10);
+    if (turn_random_number() % 10 == 0) {
+      int np = (int)((unsigned long)turn_random_number() % 10);
       while (np-- > 0) {
-        int pos = (int)((unsigned long)turn_random() % (unsigned long)message->len);
-        int val = (int)((unsigned long)turn_random() % 256);
+        int pos = (int)((unsigned long)turn_random_number() % (unsigned long)message->len);
+        int val = (int)((unsigned long)turn_random_number() % 256);
         message->buf[pos] = (uint8_t)val;
       }
     }
@@ -282,12 +285,14 @@ int send_buffer(app_ur_conn_info *clnet_info, stun_buffer *message, bool data_co
 
     size_t left = message->len;
 
+    ssize_t rc = 0;
+
     while (left > 0) {
       do {
         rc = send(fd, buffer, left, 0);
       } while (rc <= 0 && (socket_eintr() || socket_enobufs() || socket_eagain()));
       if (rc > 0) {
-        left -= (size_t)rc;
+        left -= rc;
         buffer += rc;
       } else {
         tot_send_dropped += 1;
@@ -701,7 +706,7 @@ static int client_read(app_ur_session *elem, int is_tcp_data, app_tcp_conn_info
           sar = stun_attr_get_next_str(elem->in_buffer.buf, elem->in_buffer.len, sar);
         }
         if (negative_test) {
-          tcp_data_connect(elem, (uint64_t)turn_random());
+          tcp_data_connect(elem, (uint64_t)turn_random_number());
         } else {
           /* positive test */
           tcp_data_connect(elem, cid);
@@ -896,7 +901,7 @@ static int client_write(app_ur_session *elem) {
     if (!(elem->pinfo.tcp_conn) || !(elem->pinfo.tcp_conn_number)) {
       return -1;
     }
-    int i = (unsigned int)(turn_random()) % elem->pinfo.tcp_conn_number;
+    int i = (unsigned int)(turn_random_number()) % elem->pinfo.tcp_conn_number;
     atc = elem->pinfo.tcp_conn[i];
     if (!atc->tcp_data_bound) {
       printf("%s: Uninitialized atc: i=%d, atc=%p\n", __FUNCTION__, i, atc);
@@ -1237,7 +1242,7 @@ static int refresh_channel(app_ur_session *elem, uint16_t method, uint32_t lt) {
     stun_attr_add(&message, STUN_ATTRIBUTE_LIFETIME, (const char *)&lt, 4);
 
     if (dual_allocation && !mobility) {
-      int t = ((uint8_t)turn_random()) % 3;
+      int t = ((uint8_t)turn_random_number()) % 3;
       if (t) {
         uint8_t field[4];
         field[0] = (t == 1) ? (uint8_t)STUN_ATTRIBUTE_REQUESTED_ADDRESS_FAMILY_VALUE_IPV4
@@ -1404,6 +1409,10 @@ void start_mclient(const char *remote_address, int port, const unsigned char *if
   }
 
   elems = (app_ur_session **)malloc(sizeof(app_ur_session) * ((mclient * 2) + 1) + sizeof(void *));
+  if (elems == NULL) {
+    TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "!!! %s: failure in call to malloc !!!\n", __FUNCTION__);
+    return;
+  }
 
   __turn_getMSTime();
   uint32_t stime = current_time;
@@ -1480,7 +1489,7 @@ void start_mclient(const char *remote_address, int port, const unsigned char *if
 
     if (is_TCP_relay()) {
       if (passive_tcp) {
-        if (elems[i]->pinfo.is_peer) {
+        if (elems && elems[i]->pinfo.is_peer) {
           int connect_err = 0;
           socket_connect(elems[i]->pinfo.fd, &(elems[i]->pinfo.remote_addr), &connect_err);
         }
@@ -1541,7 +1550,7 @@ void start_mclient(const char *remote_address, int port, const unsigned char *if
   stime = current_time;
 
   for (int i = 0; i < total_clients; i++) {
-    elems[i]->to_send_timems = current_mstime + 1000 + ((uint32_t)turn_random()) % 5000;
+    elems[i]->to_send_timems = current_mstime + 1000 + ((uint32_t)turn_random_number()) % 5000;
   }
 
   tot_messages = elems[0]->tot_msgnum * total_clients;
@@ -1612,7 +1621,7 @@ int add_integrity(app_ur_conn_info *clnet_info, stun_buffer *message) {
 
       if (((method == STUN_METHOD_ALLOCATE) || (method == STUN_METHOD_REFRESH)) || !(clnet_info->key_set)) {
 
-        cok = ((unsigned short)turn_random()) % 3;
+        cok = ((unsigned short)turn_random_number()) % 3;
         clnet_info->cok = cok;
         oauth_token otoken;
         encoded_oauth_token etoken;
@@ -1621,7 +1630,7 @@ int add_integrity(app_ur_conn_info *clnet_info, stun_buffer *message) {
         long halflifetime = OAUTH_SESSION_LIFETIME / 2;
         long random_lifetime = 0;
         while (!random_lifetime) {
-          random_lifetime = turn_random();
+          random_lifetime = turn_random_number();
         }
         if (random_lifetime < 0) {
           random_lifetime = -random_lifetime;
