@@ -1,4 +1,8 @@
 /*
+ * SPDX-License-Identifier: BSD-3-Clause
+ *
+ * https://opensource.org/license/bsd-3-clause
+ *
  * Copyright (C) 2011, 2012, 2013 Citrix Systems
  *
  * All rights reserved.
@@ -33,8 +37,9 @@
 #include "ns_turn_msg_defs.h" // for STUN_VALID_CHANNEL
 #include "ns_turn_utils.h"    // for TURN_LOG_FUNC, TURN_LOG_LEVEL_ERROR
 
-#include <stdlib.h> // for NULL, size_t, free, realloc, calloc
-#include <string.h> // for memset, memcpy
+#include <stdbool.h> // for bool, false, true
+#include <stdlib.h>  // for NULL, size_t, free, realloc, calloc
+#include <string.h>  // for memset, memcpy
 
 /////////////// Permission forward declarations /////////////////
 
@@ -238,7 +243,7 @@ static turn_permission_info *get_from_turn_permission_hashtable(turn_permission_
     return NULL;
   }
 
-  uint32_t index = addr_hash_no_port(addr) & (TURN_PERMISSION_HASHTABLE_SIZE - 1);
+  const uint32_t index = addr_hash_no_port(addr) & (TURN_PERMISSION_HASHTABLE_SIZE - 1);
   turn_permission_array *parray = &(map->table[index]);
 
   for (size_t i = 0; i < TURN_PERMISSION_ARRAY_SIZE; ++i) {
@@ -292,7 +297,7 @@ void turn_channel_delete(ch_info *chn) {
     return;
   }
 
-  int port = addr_get_port(&(chn->peer_addr));
+  const int port = addr_get_port(&(chn->peer_addr));
   if (port < 1) {
     char s[129];
     addr_to_string(&(chn->peer_addr), (uint8_t *)s);
@@ -386,8 +391,8 @@ turn_permission_info *allocation_add_permission(allocation *a, const ioa_addr *a
   }
 
   turn_permission_hashtable *map = &(a->addr_to_perm);
-  uint32_t hash = addr_hash_no_port(addr);
-  size_t fds = (size_t)(hash & (TURN_PERMISSION_HASHTABLE_SIZE - 1));
+  const uint32_t hash = addr_hash_no_port(addr);
+  const size_t fds = (size_t)(hash & (TURN_PERMISSION_HASHTABLE_SIZE - 1));
 
   turn_permission_array *parray = &(map->table[fds]);
 
@@ -546,7 +551,7 @@ static void set_new_tc_id(uint8_t server_id, tcp_connection *tc) {
   uint32_t newid = 0;
   do {
     do {
-      newid = ((uint32_t)turn_random()) & 0x00FFFFFF;
+      newid = ((uint32_t)turn_random_number()) & 0x00FFFFFF;
     } while (!newid);
     newid = newid | sid;
   } while (ur_map_get(a->tcp_connections, (ur_map_key_type)newid, NULL));
@@ -556,7 +561,7 @@ static void set_new_tc_id(uint8_t server_id, tcp_connection *tc) {
 
 tcp_connection *create_tcp_connection(uint8_t server_id, allocation *a, stun_tid *tid, ioa_addr *peer_addr,
                                       int *err_code) {
-  tcp_connection_list *tcl = &(a->tcs);
+  tcp_connection_list *const tcl = &(a->tcs);
   if (!tcl) {
     return NULL;
   }
@@ -604,7 +609,6 @@ tcp_connection *create_tcp_connection(uint8_t server_id, allocation *a, stun_tid
     a->tcs.elems = new_elems;
     a->tcs.elems[a->tcs.sz] = tc;
     a->tcs.sz += 1;
-    tcl = &(a->tcs);
   }
 
   set_new_tc_id(server_id, tc);
@@ -721,6 +725,11 @@ void add_unsent_buffer(unsent_buffer *ub, ioa_network_buffer_handle nbh) {
     ioa_network_buffer_delete(NULL, nbh);
   } else {
     ub->bufs = (ioa_network_buffer_handle *)realloc(ub->bufs, sizeof(ioa_network_buffer_handle) * (ub->sz + 1));
+    if (!ub->bufs) {
+      TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Memory allocation failed in add_unsent_buffer\n");
+      ioa_network_buffer_delete(NULL, nbh);
+      return;
+    }
     ub->bufs[ub->sz] = nbh;
     ub->sz += 1;
   }
